import * as React from "react";
import { isEmpty } from "ramda";

import { useNavigation } from "@applicaster/zapp-react-native-utils/reactHooks/navigation";
import { getPathAttributes } from "@applicaster/zapp-react-native-utils/navigationUtils";
import { FocusableGroup } from "@applicaster/zapp-react-native-ui-components/Components/FocusableGroup";
import { ScreenDataContext } from "@applicaster/zapp-react-native-ui-components/Contexts/ScreenDataContext";
import { PathnameContext } from "@applicaster/zapp-react-native-ui-components/Contexts/PathnameContext";

import { Screen } from "../Screen/TV/index.web";

type Components = {
  NavBar: React.ComponentType<any>;
  Background: React.ComponentType<any>;
};

type Props = {
  Components: Components;
};

export const StackNavigator = ({ Components }: Props) => {
  const { mainStack, currentRoute } = useNavigation();

  const renderScreen = ({ route, state }) => {
    const pathAttributes = getPathAttributes({ pathname: route });

    if (isEmpty(pathAttributes)) {
      return null;
    }

    return (
      <FocusableGroup
        id={route}
        preferredFocus={route === currentRoute}
        excludeFromFocusSearching
        key={route}
      >
        <ScreenDataContext.Provider value={state}>
          <PathnameContext.Provider value={route}>
            <Screen route={route} Components={Components} />
          </PathnameContext.Provider>
        </ScreenDataContext.Provider>
      </FocusableGroup>
    );
  };

  return <>{mainStack.map(renderScreen)}</>;
};
